{ config, lib, pkgs, ... }:

{
  # Upgrade Doom Emacs daily
  systemd.user.services.doom-upgrade = {
    description = "Upgrade Doom Emacs";
    path = with pkgs; [ bash emacsPgtkGcc git coreutils ];
    script = ''
      ${pkgs.bash}/bin/bash -c "/home/coolneng/.emacs.d/bin/doom -y upgrade"
    '';
    serviceConfig.Type = "oneshot";
    startAt = "22:00:00";
  };

  # Clean up Doom Emacs monthly
  systemd.user.services.doom-purge = {
    description = "Purge Doom Emacs";
    path = with pkgs; [ bash emacsPgtkGcc git coreutils ];
    script = ''
      ${pkgs.bash}/bin/bash -c "/home/coolneng/.emacs.d/bin/doom -y purge"
    '';
    serviceConfig.Type = "oneshot";
    startAt = "13-*-* 20:00:00";
  };

  # Upgrade Neovim plugins weekly
  systemd.user.services.vim-plug-upgrade = {
    description = "Upgrade Vim-Plug";
    path = [ pkgs.git pkgs.neovim ];
    script = "${pkgs.neovim}/bin/nvim +PlugUpgrade +PlugUpdate +qa";
    serviceConfig.Type = "oneshot";
    startAt = "Wed 18:00:00";
  };

  # Push password-store changes to git daily
  systemd.user.services.password-store-push = {
    description = "Push password-store changes to git";
    path = [ pkgs.pass-wayland pkgs.git pkgs.gitAndTools.pass-git-helper ];
    script = "${pkgs.pass-wayland}/bin/pass git push";
    serviceConfig.Type = "oneshot";
    startAt = "18:00:00";
  };

}
